Alexis' log

# Archives for Alexis' log

Fri 30 November 2012
  FILENAME_METADATA example
Wed 29 February 2012
  Second article
Wed 20 April 2011
  A markdown powered article
Thu 17 February 2011
  Article 1
Thu 17 February 2011
  Article 2
Thu 17 February 2011
  Article 3
Thu 02 December 2010
  This is a super article !
Wed 20 October 2010
  Oh yeah !
Fri 15 October 2010
  Unbelievable !
Sun 14 March 2010
  The baz tag

## links

- Biologeek
- Filyb
- Libert-fr
- N1k0
- Tarek Ziadé
- Zubin Mithra

## social

- atom feed
- rss feed
- twitter
- lastfm
- github